-- This is a sample Max script that imports baked curves onto blendshapes.  It
-- demonstrates how to get curves from a FaceFX animation and import them into 
-- Max correctly. The script loops through all morph tracks in the selected object.  
-- If the name of a track matches the name of curve that exists in the given group 
-- and animation, all keys in the morph track will be deleted and replaced with 
-- keys representing an accurate approximation of the FaceFX node's value in the 
-- animation.  Make sure the morphed object is selected.
fn FxImportRawCurves group anim =
(
	
	-- Create FaceFX object
	FaceFXobj = FaceFX();
	
	-- set the animation range.  Start at frame -5 to handle any negative keys
	animationRange.start = -5f;
	animEndTime = FaceFXobj.fxgetanimduration group anim;
	animEndTime  *= frameRate;
	animationRange = interval -5 animEndTime   
		
	morpherObject = $.modifiers[#Morpher];
	if morpherObject != undefined then
	(
		for i = 1 to 100 do
		(
			curve = WM3_MC_GetName morpherObject i
			times = FaceFXobj.fxgetbakedcurvekeytimes group anim curve;
			values = FaceFXobj.fxgetbakedcurvekeyvalues group anim curve;
			slopein = FaceFXobj.fxgetbakedcurvekeyslopein group anim curve;
			slopeout = FaceFXobj.fxgetbakedcurvekeyslopeout group anim curve;
			
			for j = 1 to times.count do
			(
				-- Delete any existing keys
				if j == 1 then deletekeys morpherObject[i].controller;
				key = addNewKey morpherObject[i].controller (times[j]*frameRate);
				key.value = values[j] * 100;   
				key.x_locked = false;
				key.y_locked = false;
				key.z_locked = false;
				key.inTangent =  -1 * slopein[j];
				key.outTangent =  slopeout[j];
				-- The below tangent lengths were adjusted by hand to match the 
				-- FaceFX hermite interpolation algorithm. 
				key.inTangentLength = .21;
				key.outTangentLength = .21;
			)
		)	
	)
	else
	(
		messageBox "Error: No morpher modifier found in selected object";
	)
)
-- Call the Function like this:
-- FxImportRawCurves "Default" "welcome";