--------------------------------------------------------------------------------
-- Actor File Exporter for Slade-Max.fxa
--
-- Owner: Doug Perkowski
--
-- Copyright (c) 2002-2008 OC3 Entertainment, Inc.  All Rights Reserved.
--------------------------------------------------------------------------------

-- Instructions:
-- To run the script, open Slade-Max.max, then go to MAXScript->Open Script
-- and select this file. From the script window, go to File->Evaluate All.
-- This script will not run if you select MAXScript->Run Script.  It fails when the 
-- FaceFX object is declared.  This is a known issue with the max plug-in.
--
-- This script demonstrates how to export an actor with Maxscript.  It can be 
-- used on the Slade-Max.max file.  In fact the Slade-Max actor file can be
-- automatically generated with this Maxscript and the included .fxl file
-- which sets up the Face Graph.  This creates the Slade actor without any 
-- animations.  Adding animations can also be done proceedurally from the 
-- FaceFX command system, but this would require source audio.


--------------------------------------------------------------------------------
-- Variables  
--------------------------------------------------------------------------------
FxBone_Name_Array = #("BN_Root", "BN_Neck", "BN_Head", "BN_Lips_Corner_R", "BN_Lips_Upper_Outer_R", "BN_Lips_Upper_Inner_R", "BN_Lips_Upper_C", "BN_Lips_Upper_Inner_L", "BN_Lips_Corner_L", "BN_Lips_Upper_Outer_L", "BN_Blink_Upper_R", "BN_Nostral_R", "BN_Eyebrow_Inner_R", "BN_Cheek_Low_R", "BN_Cheek_High_R", "BN_Eyebrow_Outer_R", "BN_Eyeball_R", "BN_Blink_Lower_L", "BN_Blink_Lower_R", "BN_Blink_Upper_L", "BN_Cheek_High_L", "BN_Cheek_Low_L", "BN_Ear_L", "BN_Ear_R", "BN_Eyeball_L", "BN_Eyebrow_C", "BN_Eyebrow_Inner_L", "BN_Eyebrow_Outer_L", "BN_Jaw_Pivot", "BN_Jaw", "BN_Lips_Lower_C", "BN_Lips_Lower_Inner_L", "BN_Lips_Lower_Inner_R", "BN_Lips_Lower_Outer_L", "BN_Lips_Lower_Outer_R", "BN_Nostral_L", "BN_Tongue_Back", "BN_Tongue_Front_L", "BN_Tongue_Front_R", "BN_Tongue_L", "BN_Tongue_R", "BN_Eyeball_Dilate_R", "BN_Eyeball_Dilate_L", "BN_Blink_Lower_In_L", "BN_Blink_Lower_Out_L", "BN_Blink_Upper_In_L", "BN_Blink_Upper_Out_L", "BN_Blink_Lower_In_R", "BN_Blink_Lower_Out_R", "BN_Blink_Upper_In_R", "BN_Blink_Upper_Out_R");


POSES = #("Neutral", "open", "W", "ShCh", "PBM", "FV", "wide", "tBack", "tRoof", "tTeeth", "Blink_Left", "Blink_Right", "Eyebrow_Raise_Left", "Eyebrow_Raise_Right", "Pupils_Dilate", "Lid_Upper_Out_Left", "Lid_Upper_In_Left", "Lid_Upper_In_Right", "Lid_Upper_Out_Right", "Lid_Upper_C_Left", "Lid_Upper_C_Right","Lid_Lower_Out_Left", "Lid_Lower_In_Left", "Lid_Lower_In_Right", "Lid_Lower_Out_Right", "Lid_Lower_C_Left", "Lid_Lower_C_Right", "BN_Neck_RotPos_X", "BN_Neck_RotPos_Y", "BN_Head_RotPos_X", "BN_Head_RotPos_Y", "BN_Head_RotPos_Z", "BN_Eyeball_L_RotPos_X", "BN_Eyeball_L_RotPos_Y",  "BN_Eyeball_R_RotPos_X", "BN_Eyeball_R_RotPos_Y",  "BN_Neck_RotNeg_X", "BN_Neck_RotNeg_Y", "BN_Head_RotNeg_X", "BN_Head_RotNeg_Y", "BN_Head_RotNeg_Z", "BN_Eyeball_L_RotNeg_X", "BN_Eyeball_L_RotNeg_Y",  "BN_Eyeball_R_RotNeg_X", "BN_Eyeball_R_RotNeg_Y", "AU1-Inner Brow Raiser Left", "AU1-Inner Brow Raiser Right", "AU2-Outer Brow Raiser Left", "AU2-Outer Brow Raiser Right", "AU4-Brow Lowerer Left", "AU4-Brow Lowerer Right", "AU9-Nose Wrinkler", "AU10-Upper Lip Raiser",  "AU12-Lip Corner Puller Left", "AU12-Lip Corner Puller Right", "AU13-Sharp Lip Puller Left",  "AU13-Sharp Lip Puller Right", "AU15-Lip Corner Depressor Left", "AU15-Lip Corner Depressor Right", "AU16-Lower Lip Depressor", "AU17-chin Raiser", "AU18-Lip Pucker",  "AU20-Lip Stretcher",  "AU22-Lip Funneler", "AU23-Lip Tightener", "AU24-Lip Presser", "AU25-Lips Part", "AU26-Jaw Drop", "AU27-Mouth Stretch", "AU28-Lips Suck", "AU29-Jaw Thrust", "AU30-Jaw Sideways", "AU38-Nostril Dilator", "AU39-Nostril Compressor", "Toungue_Push_Center", "Toungue_Push_Front", "Toungue_Up_Center", "Toungue_Up_Front", "Cheek_Up_Left", "Cheek_Up_Right", "Ear_Up_Left", "Ear_Up_Right", "Snarl_Left", "Snarl_Right", "BN_Neck_Pos_X", "BN_Neck_Pos_Y", "BN_Neck_Pos_Z", "BN_Head_Pos_X", "BN_Head_Pos_Y", "BN_Head_Pos_Z", "Look_Left_Lids", "Look_Right_Lids", "Look_Up_Lids", "Look_Down_Lids", "Look_Left_Eyeballs", "Look_Right_Eyeballs", "Look_Up_Eyeballs", "Look_Down_Eyeballs");

FxActorName = "Slade-Max";

-- Create FaceFX object
FaceFXobj = FaceFX();

-- Turn off Normalize Scale so we can export the Pupils_Dilate pose that uses Scale.  
-- Slade doesn't use non-uniform scale or character studio, so this isn't a problem.
FaceFXobj.fxsetnormalizescale "off";

FaceFXobj.fxcreateactor FxActorName;

FaceFXobj.fxexportrefpose 0 FxBone_Name_Array;

-- Turn off warning dialogs before exporting poses so we don't get warnings for the
-- Neutral pose or all poses if the character isn't loaded.
FaceFXobj.fxsetdisplaywarningdialogs "off";

i =0;
for POSE in POSES do
(
	frame = i * 10;
	FaceFXobj.fxexportbonepose frame POSE;
	i = i + 1;
)

FaceFXobj.fxsetdisplaywarningdialogs "on";

-- Path of saved actor file.  To do this completely from script, you would need something like:  "C:\Slade-Max.fxa";
FxActorpath = getSaveFileName\
	caption:"Save Generated FXA File"\
	types:"FaceFX Actor File(*.FXA)";
FaceFXobj.fxsaveactor FxActorpath;